pub struct Session<Io> { /* private fields */ }Expand description
A TLSNotary session over a communication channel.
Wraps an async IO stream and provides multiplexing for the protocol. Use
new_prover or new_verifier to
create protocol participants.
The session must be polled continuously (either directly or via
split) to drive the underlying connection. After the
session closes, the underlying IO can be reclaimed with
try_take.
Important: The order in which provers and verifiers are created must
match on both sides. For example, if the prover side calls new_prover
then new_verifier, the verifier side must call new_verifier then
new_prover.
Implementations
Sourceimpl<Io> Session<Io>where
Io: AsyncRead + AsyncWrite + Unpin,
impl<Io> Session<Io>where
Io: AsyncRead + AsyncWrite + Unpin,
Sourcepub fn new_prover(
&mut self,
config: ProverConfig,
) -> Result<Prover<Initialized>>
pub fn new_prover( &mut self, config: ProverConfig, ) -> Result<Prover<Initialized>>
Creates a new prover.
Sourcepub fn new_verifier(
&mut self,
config: VerifierConfig,
) -> Result<Verifier<Initialized>>
pub fn new_verifier( &mut self, config: VerifierConfig, ) -> Result<Verifier<Initialized>>
Creates a new verifier.
Sourcepub fn close(&mut self)
pub fn close(&mut self)
Closes the session.
This will cause the session to begin closing. Session must continue to be polled until completion.
Sourcepub fn try_take(&mut self) -> Result<Io>
pub fn try_take(&mut self) -> Result<Io>
Attempts to take the IO, returning an error if it is not available.
Sourcepub fn split(self) -> (SessionDriver<Io>, SessionHandle)
pub fn split(self) -> (SessionDriver<Io>, SessionHandle)
Splits the session into a driver and handle.
The driver must be polled to make progress. The handle is used for creating provers/verifiers and closing the session.